@@ -320,11 +320,12 @@ class LPMain:
         x = np.array(problem.solution.get_values())
         return x
             
-    def show_lp_system(self,window_size="1225x850"):
+    def show_lp_system(self,window_size="1225x850",width=500):
         '''
         Displays a graphical user interface (GUI) for visualizing the Linear Programming (LP) system. 
         Sets up a Tkinter window with a notebook interface, creating tabs for each object in 'obj_lst'. 
         There is no auto formatting yet. This function is still in an early state.
+        If the equation is to wide for hte window, increase the width
         '''
         root = tk.Tk()
         root.title("MILP System")
@@ -340,7 +341,6 @@ class LPMain:
             frame = tab.scrollable_frame
 
             heading_font = tkfont.Font(size=16, weight="bold")
-            width=500
 
             if len(obj.stateVar_lst) > 0:
                 # Display state variables in table
